==> mesa-18.2.7.tar.xz: mesa-18.2.7/src/gallium/drivers/swr/swr_query.h <==
/****************************************************************************
 * Copyright (C) 2015 Intel Corporation.   All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 ***************************************************************************/

#ifndef SWR_QUERY_H
#define SWR_QUERY_H


#include <limits.h>

struct swr_query_result {
   SWR_STATS core;
   SWR_STATS_FE coreFE;
   uint64_t timestamp_start;
   uint64_t timestamp_end;
};

OSALIGNLINE(struct) swr_query {
   unsigned type; /* PIPE_QUERY_* */
   unsigned index;

   struct swr_query_result result;
   struct pipe_fence_handle *fence;
};

extern void swr_query_init(struct pipe_context *pipe);

extern boolean swr_check_render_cond(struct pipe_context *pipe);
#endif

==> mesa_21.3.8.3.orig.tar.xz: mesa-21.3.8.3/src/gallium/drivers/swr/swr_query.h <==
/****************************************************************************
 * Copyright (C) 2015 Intel Corporation.   All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 ***************************************************************************/

#ifndef SWR_QUERY_H
#define SWR_QUERY_H


#include <limits.h>

struct swr_query_result {
   SWR_STATS core;
   SWR_STATS_FE coreFE;
   uint64_t timestamp_start;
   uint64_t timestamp_end;
};

OSALIGNLINE(struct) swr_query {
   unsigned type; /* PIPE_QUERY_* */
   unsigned index;

   struct swr_query_result result;
   struct pipe_fence_handle *fence;
};

extern void swr_query_init(struct pipe_context *pipe);

extern bool swr_check_render_cond(struct pipe_context *pipe);
#endif
